@@ -4,10 +4,10 @@ from sqlalchemy.orm import relationship
 
 # Availability class is used, so we must define it here or else it has to be definied by clients of the Group class,
 # and they don't necessarily know that they need to do this
-from .user import User
-from .availability import Availability
-from .group_admins_link import group_admins_link
-from .group_members_link import group_members_link
+# from .user import User
+# from .availability import Availability
+# from .group_admins_link import group_admins_link
+# from .group_members_link import group_members_link
 
 
 class Group(Base):
